@@ -23,6 +23,10 @@ class ContextDict:
         except KeyError:
             return default
 
+    def setdefault(self, key: str, default):
+        self.storage.data.setdefault(key, default)
+        self.storage.save()
+
     def clear(self):
         self.storage.data.clear()
         self.storage.save()
