@@ -1,4 +1,6 @@
 import inspect
+from threading import Thread
+
 from ..base.user_proxy_model import UserProxyModel
 from ..base.exceptions import StopProcessing, ExitHandler
 from ..context import ctx
@@ -98,7 +100,7 @@ def process_update(update: Update) -> None:
 
 def process_updates(updates: list[Update]):
     for update in updates:
-        process_update(update)
+        Thread(target=lambda: process_update(update)).start()
 
 
 def start_polling(skip_updates: bool):
